# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DatabaseSqlResponse(UniversalBaseModel):
    """
    Response for direct SQL execution.

    For SELECT queries, ``columns`` and ``rows`` are populated.
    For non-SELECT statements (DDL/DML), ``statuses`` is populated.
    """

    columns: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Column names (populated for SELECT queries)
    """

    rows: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(default=None)
    """
    Row data as objects (populated for SELECT queries)
    """

    statuses: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Execution statuses (populated for non-SELECT statements)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
